@@ -121,10 +121,7 @@ FitGenGamma <- function(
   
   # Inverse information.
   inv_info <- solve(info)
-
-  if (any(diag(inv_info) < 0)) {
-    stop("Information matrix not positive definite. Try another initialization")
-  }
+  CheckInfoPD(inv_info)
 
   # Parameter frame.
   params <- data.frame(
@@ -183,23 +180,8 @@ FitGenGamma <- function(
     SE = c(se_mu, se_me, se_v),
     stringsAsFactors = FALSE
   )
-  
-  # Confidence intervals.
-  Estimate <- NULL
-  SE <- NULL
-  z <- stats::qnorm(1 - sig / 2)
-  
-  params <- params %>%
-    dplyr::mutate(
-      L = Estimate - z * SE,
-      U = Estimate + z * SE
-    )
-  
-  outcome <- outcome %>%
-    dplyr::mutate(
-      L = Estimate - z * SE,
-      U = Estimate + z * SE
-    )
+  params <- AddCIs(params, sig)
+  outcome <- AddCIs(outcome, sig)
 
   # Fitted survival function
   alpha <- theta[1]
@@ -223,8 +205,10 @@ FitGenGamma <- function(
   if (is.numeric(tau)) {
     rmst <- ParaRMST(fit = out, sig = sig, tau = tau)
     out@RMST <- rmst
+  } else {
+    out@RMST <- data.frame()
   }
-  
+
   return(out)
 }
 
@@ -256,7 +240,7 @@ GenGammaRate <- function(data, alpha, beta) {
 #' 
 #' @param data Data.frame.
 #' @param beta Second shape parameter.
-#' @return Numeric MLE of the rate \eqn{\alpha}.
+#' @return Numeric MLE of the first shape parameter \eqn{\alpha}.
 GenGammaShape <- function(data, beta) {
   n <- nrow(data)
   time <- data$time
